@@ -27,17 +27,9 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 #include <osmium/handler/node_locations_for_ways.hpp>
 #include <osmium/index/map/all.hpp>
-
-namespace osmium {
-
-    namespace io {
-        class Reader;
-        class Writer;
-    } // namespace io
-
-    class ProgressBar;
-
-} // namespace osmium
+#include <osmium/io/reader.hpp>
+#include <osmium/io/writer.hpp>
+#include <osmium/util/progress_bar.hpp>
 
 #include <string>
 #include <vector>
@@ -47,12 +39,12 @@ using location_handler_type = osmium::handler::NodeLocationsForWays<index_type>;
 
 class CommandAddLocationsToWays : public Command, public with_multiple_osm_inputs, public with_osm_output {
 
-    void copy_data(osmium::ProgressBar& progress_bar, osmium::io::Reader& reader, osmium::io::Writer& writer, location_handler_type& location_handler);
-
     std::string m_index_type_name;
     bool m_keep_untagged_nodes = false;
     bool m_ignore_missing_nodes = false;
 
+    void copy_data(osmium::ProgressBar& progress_bar, osmium::io::Reader& reader, osmium::io::Writer& writer, location_handler_type& location_handler);
+
 public:
 
     explicit CommandAddLocationsToWays(const CommandFactory& command_factory) :
