@@ -1,9 +1,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,14 +20,9 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <algorithm>
-#include <stdexcept>
-#include <string>
-#include <utility>
-#include <vector>
-
-#include <boost/function_output_iterator.hpp>
-#include <boost/program_options.hpp>
+#include "command_apply_changes.hpp"
+#include "exception.hpp"
+#include "util.hpp"
 
 #include <osmium/index/id_set.hpp>
 #include <osmium/index/map/sparse_mem_array.hpp>
@@ -36,6 +31,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <osmium/io/input_iterator.hpp>
 #include <osmium/io/output_iterator.hpp>
 #include <osmium/io/reader.hpp>
+#include <osmium/io/reader_with_progress_bar.hpp>
 #include <osmium/io/writer.hpp>
 #include <osmium/memory/buffer.hpp>
 #include <osmium/object_pointer_collection.hpp>
@@ -43,13 +39,17 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <osmium/osm/object.hpp>
 #include <osmium/osm/object_comparisons.hpp>
 #include <osmium/osm/types.hpp>
-#include <osmium/util/progress_bar.hpp>
 #include <osmium/util/verbose_output.hpp>
 #include <osmium/visitor.hpp>
 
-#include "command_apply_changes.hpp"
-#include "exception.hpp"
-#include "util.hpp"
+#include <boost/function_output_iterator.hpp>
+#include <boost/program_options.hpp>
+
+#include <algorithm>
+#include <stdexcept>
+#include <string>
+#include <utility>
+#include <vector>
 
 using location_index_type = osmium::index::map::SparseMemArray<osmium::unsigned_object_id_type, osmium::Location>;
 
@@ -58,6 +58,7 @@ bool CommandApplyChanges::setup(const std::vector<std::string>& arguments) {
     opts_cmd.add_options()
     ("change-file-format", po::value<std::string>(), "Format of the change file(s)")
     ("simplify,s",        "Simplify change (deprecated)")
+    ("redact",            "Redact (patch) OSM files")
     ("remove-deleted,r",  "Remove deleted objects from output (deprecated)")
     ("with-history,H",    "Apply changes to history file")
     ("locations-on-ways", "Expect and update locations on ways")
@@ -88,6 +89,7 @@ bool CommandApplyChanges::setup(const std::vector<std::string>& arguments) {
     po::notify(vm);
 
     setup_common(vm, desc);
+    setup_progress(vm);
     setup_input_file(vm);
     setup_output_file(vm);
 
@@ -113,12 +115,24 @@ bool CommandApplyChanges::setup(const std::vector<std::string>& arguments) {
         m_output_file.set_has_multiple_object_versions(true);
     } else {
         if (m_input_file.has_multiple_object_versions() && m_output_file.has_multiple_object_versions()) {
+            if (m_locations_on_ways) {
+                throw argument_error{"Can not use --locations-on-ways on history files."};
+            }
             m_with_history = true;
         } else if (m_input_file.has_multiple_object_versions() != m_output_file.has_multiple_object_versions()) {
             throw argument_error{"Input and output file must both be OSM data files or both OSM history files (force with --with-history)."};
         }
     }
 
+    if (vm.count("redact")) {
+        if (m_locations_on_ways) {
+            throw argument_error{"Can not use --redact and --locations-on-ways together."};
+        }
+        m_with_history = true;
+        m_redact = true;
+        m_output_file.set_has_multiple_object_versions(true);
+    }
+
     if (vm.count("simplify")) {
         warning("-s, --simplify option is deprecated. Please see manual page.\n");
         m_with_history = false;
@@ -212,7 +226,7 @@ bool CommandApplyChanges::run() {
     }
 
     m_vout << "Opening input file...\n";
-    osmium::io::Reader reader{m_input_file, osmium::osm_entity_bits::object};
+    osmium::io::ReaderWithProgressBar reader{display_progress(), m_input_file, osmium::osm_entity_bits::object};
 
     osmium::io::Header header;
     setup_header(header);
@@ -233,14 +247,24 @@ bool CommandApplyChanges::run() {
         m_vout << "Sorting change data...\n";
         objects.sort(osmium::object_order_type_id_version());
 
+        m_vout << "Applying changes and writing them to output...\n";
         const auto input = osmium::io::make_input_iterator_range<osmium::OSMObject>(reader);
         auto out = osmium::io::make_output_iterator(writer);
-        m_vout << "Applying changes and writing them to output...\n";
-        std::set_union(objects.begin(),
-                       objects.end(),
-                       input.begin(),
-                       input.end(),
-                       out);
+
+        if (m_redact) {
+            std::set_union(objects.begin(),
+                           objects.end(),
+                           input.begin(),
+                           input.end(),
+                           out,
+                           osmium::object_order_type_id_version_without_timestamp());
+        } else {
+            std::set_union(objects.begin(),
+                           objects.end(),
+                           input.begin(),
+                           input.end(),
+                           out);
+        }
     } else {
         // For normal data files we sort with the largest version of each
         // object first and then only copy this last version of any object
@@ -276,9 +300,7 @@ bool CommandApplyChanges::run() {
             m_vout << "Applying changes and writing them to output...\n";
             auto it = objects.begin();
             auto last_type = osmium::item_type::undefined;
-            osmium::ProgressBar progress_bar{reader.file_size(), display_progress()};
             while (osmium::memory::Buffer buffer = reader.read()) {
-                progress_bar.update(reader.offset());
                 for (auto& object : buffer.select<osmium::OSMObject>()) {
                     if (object.type() < last_type) {
                         throw std::runtime_error{"Input data out of order. Need nodes, ways, relations in ID order."};
@@ -323,14 +345,13 @@ bool CommandApplyChanges::run() {
                 }
                 ++it;
             }
-            progress_bar.done();
         } else {
+            m_vout << "Applying changes and writing them to output...\n";
             const auto input = osmium::io::make_input_iterator_range<osmium::OSMObject>(reader);
             auto output_it = boost::make_function_output_iterator(
                                 copy_first_with_id(writer)
             );
 
-            m_vout << "Applying changes and writing them to output...\n";
             std::set_union(objects.begin(),
                            objects.end(),
                            input.begin(),
