@@ -1,9 +1,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,14 +20,8 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <algorithm>
-#include <cstdint>
-#include <iostream>
-#include <string>
-#include <utility>
-#include <vector>
-
-#include <boost/program_options.hpp>
+#include "command_check_refs.hpp"
+#include "util.hpp"
 
 #include <osmium/handler.hpp>
 #include <osmium/handler/check_order.hpp>
@@ -39,8 +33,14 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <osmium/util/verbose_output.hpp>
 #include <osmium/visitor.hpp>
 
-#include "command_check_refs.hpp"
-#include "util.hpp"
+#include <boost/program_options.hpp>
+
+#include <algorithm>
+#include <cstdint>
+#include <iostream>
+#include <string>
+#include <utility>
+#include <vector>
 
 bool CommandCheckRefs::setup(const std::vector<std::string>& arguments) {
     po::options_description opts_cmd{"COMMAND OPTIONS"};
@@ -109,7 +109,7 @@ class RefCheckHandler : public osmium::handler::Handler {
     uint64_t m_missing_nodes_in_relations = 0;
     uint64_t m_missing_ways_in_relations = 0;
 
-    osmium::util::VerboseOutput& m_vout;
+    osmium::VerboseOutput& m_vout;
     osmium::ProgressBar& m_progress_bar;
     bool m_show_ids;
     bool m_check_relations;
@@ -124,7 +124,7 @@ class RefCheckHandler : public osmium::handler::Handler {
 
 public:
 
-    RefCheckHandler(osmium::util::VerboseOutput& vout, osmium::ProgressBar& progress_bar, bool show_ids, bool check_relations) :
+    RefCheckHandler(osmium::VerboseOutput& vout, osmium::ProgressBar& progress_bar, bool show_ids, bool check_relations) :
         m_vout(vout),
         m_progress_bar(progress_bar),
         m_show_ids(show_ids),
