@@ -1,9 +1,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,32 +20,33 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <cstdint>
-#include <iostream>
-#include <memory>
-#include <sstream>
-#include <string>
-#include <vector>
-
-#include <boost/crc.hpp>
-#include <boost/program_options.hpp>
+#include "command_diff.hpp"
+#include "exception.hpp"
+#include "util.hpp"
 
 #include <osmium/io/detail/read_write.hpp>
 #include <osmium/io/file.hpp>
 #include <osmium/io/file_format.hpp>
 #include <osmium/io/input_iterator.hpp>
 #include <osmium/io/reader.hpp>
+#include <osmium/io/reader_with_progress_bar.hpp>
 #include <osmium/io/writer.hpp>
 #include <osmium/io/writer_options.hpp>
 #include <osmium/memory/item.hpp>
 #include <osmium/osm.hpp>
 #include <osmium/osm/crc.hpp>
+#include <osmium/osm/crc_zlib.hpp>
 #include <osmium/osm/item_type.hpp>
 #include <osmium/util/verbose_output.hpp>
 
-#include "command_diff.hpp"
-#include "exception.hpp"
-#include "util.hpp"
+#include <boost/program_options.hpp>
+
+#include <cstdint>
+#include <iostream>
+#include <memory>
+#include <sstream>
+#include <string>
+#include <vector>
 
 bool CommandDiff::setup(const std::vector<std::string>& arguments) {
     po::options_description opts_cmd{"COMMAND OPTIONS"};
@@ -81,6 +82,7 @@ bool CommandDiff::setup(const std::vector<std::string>& arguments) {
     po::notify(vm);
 
     setup_common(vm, desc);
+    setup_progress(vm);
     setup_object_type_nwr(vm);
     setup_input_files(vm);
 
@@ -117,7 +119,7 @@ bool CommandDiff::setup(const std::vector<std::string>& arguments) {
     }
 
     if (m_output_action.empty()) {
-        if (m_output_format == "" && (m_output_filename == "" || m_output_filename == "-")) {
+        if (m_output_format.empty() && (m_output_filename.empty() || m_output_filename == "-")) {
             m_output_format = "compact";
             m_output_action = "compact";
         } else {
@@ -154,8 +156,15 @@ class OutputAction {
 
 public:
 
-    virtual ~OutputAction() {
-    }
+    OutputAction() noexcept = default;
+
+    virtual ~OutputAction() noexcept = default;
+
+    OutputAction(const OutputAction&) = delete;
+    OutputAction& operator=(const OutputAction&) = delete;
+
+    OutputAction(OutputAction&&) noexcept = delete;
+    OutputAction& operator=(OutputAction&&) noexcept = delete;
 
     virtual void left(osmium::OSMObject& /* object */) {
     }
@@ -238,7 +247,7 @@ public:
 
 bool CommandDiff::run() {
     osmium::io::Reader reader1{m_input_files[0], osm_entity_bits()};
-    osmium::io::Reader reader2{m_input_files[1], osm_entity_bits()};
+    osmium::io::ReaderWithProgressBar reader2{display_progress(), m_input_files[1], osm_entity_bits()};
     auto in1 = osmium::io::make_input_iterator_range<osmium::OSMObject>(reader1);
     auto in2 = osmium::io::make_input_iterator_range<osmium::OSMObject>(reader2);
     auto it1 = in1.begin();
@@ -262,14 +271,21 @@ bool CommandDiff::run() {
     uint64_t count_different = 0;
 
     while (it1 != end1 || it2 != end2) {
-        if (it1 == end1 || *it2 < *it1) {
+        if (it2 == end2) {
+            it1->set_diff(osmium::diff_indicator_type::left);
+            ++count_left;
+            if (action) {
+                action->left(*it1);
+            }
+            ++it1;
+        } else if (it1 == end1 || *it2 < *it1) {
             it2->set_diff(osmium::diff_indicator_type::right);
             ++count_right;
             if (action) {
-                 action->right(*it2);
+                action->right(*it2);
             }
             ++it2;
-        } else if (it2 == end2 || *it1 < *it2) {
+        } else if (*it1 < *it2) {
             it1->set_diff(osmium::diff_indicator_type::left);
             ++count_left;
             if (action) {
@@ -277,8 +293,8 @@ bool CommandDiff::run() {
             }
             ++it1;
         } else { /* *it1 == *it2 */
-            osmium::CRC<boost::crc_32_type> crc1;
-            osmium::CRC<boost::crc_32_type> crc2;
+            osmium::CRC<osmium::CRC_zlib> crc1;
+            osmium::CRC<osmium::CRC_zlib> crc2;
             switch (it1->type()) {
                 case osmium::item_type::node:
                     crc1.update(static_cast<const osmium::Node&>(*it1));
