@@ -4,9 +4,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -19,15 +19,15 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
+#include "cmd.hpp" // IWYU pragma: export
+
 #include <string>
 #include <vector>
 
-#include "cmd.hpp" // IWYU pragma: export
-
 class CommandDiff : public Command, public with_multiple_osm_inputs, public with_osm_output {
 
     std::string m_output_action;
@@ -36,7 +36,9 @@ class CommandDiff : public Command, public with_multiple_osm_inputs, public with
 
 public:
 
-    CommandDiff() = default;
+    explicit CommandDiff(const CommandFactory& command_factory) :
+        Command(command_factory) {
+    }
 
     bool setup(const std::vector<std::string>& arguments) override final;
 
