@@ -4,9 +4,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,28 +23,29 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <string>
-#include <vector>
-
-#include <rapidjson/document.h>
+#include "cmd.hpp" // IWYU pragma: export
+#include "export/options.hpp"
+#include "export/ruleset.hpp"
 
 #include <osmium/handler/node_locations_for_ways.hpp>
 #include <osmium/index/map/all.hpp>
 #include <osmium/io/writer_options.hpp>
 
-#include "cmd.hpp" // IWYU pragma: export
+#include <rapidjson/document.h>
 
-#include "export/options.hpp"
+#include <string>
+#include <vector>
 
 class CommandExport : public Command, public with_single_osm_input {
 
     using index_type = osmium::index::map::Map<osmium::unsigned_object_id_type, osmium::Location>;
-    using location_handler_type = osmium::handler::NodeLocationsForWays<index_type>;
+    using location_handler_type = osmium::handler::NodeLocationsForWays<index_type, index_type>;
 
-    options_type m_options;
+    options_type m_options{};
+
+    Ruleset m_linear_ruleset;
+    Ruleset m_area_ruleset;
 
-    std::vector<std::string> m_linear_tags;
-    std::vector<std::string> m_area_tags;
     std::vector<std::string> m_include_tags;
     std::vector<std::string> m_exclude_tags;
 
@@ -53,6 +54,8 @@ class CommandExport : public Command, public with_single_osm_input {
     std::string m_output_filename;
     std::string m_output_format;
 
+    geometry_types m_geometry_types;
+
     osmium::io::overwrite m_output_overwrite = osmium::io::overwrite::no;
     osmium::io::fsync m_fsync = osmium::io::fsync::no;
 
@@ -65,7 +68,9 @@ class CommandExport : public Command, public with_single_osm_input {
 
 public:
 
-    CommandExport() = default;
+    explicit CommandExport(const CommandFactory& command_factory) :
+        Command(command_factory) {
+    }
 
     bool setup(const std::vector<std::string>& arguments) override final;
 
