@@ -46,6 +46,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <boost/program_options.hpp>
 
 #include <algorithm>
+#include <cmath>
 #include <cstdint>
 #include <iostream>
 #include <iterator>
@@ -70,6 +71,10 @@ struct InfoHandler : public osmium::handler::Handler {
     uint64_t ways       = 0;
     uint64_t relations  = 0;
 
+    uint64_t buffers_count    = 0;
+    uint64_t buffers_size     = 0;
+    uint64_t buffers_capacity = 0;
+
     osmium::min_op<osmium::object_id_type> smallest_changeset_id{};
     osmium::min_op<osmium::object_id_type> smallest_node_id{};
     osmium::min_op<osmium::object_id_type> smallest_way_id{};
@@ -287,6 +292,26 @@ public:
 
         std::cout << "  All objects have following metadata attributes: " << info_handler.metadata_all_objects  << "\n";
         std::cout << "  Some objects have following metadata attributes: " << info_handler.metadata_some_objects  << "\n";
+
+        const auto num_objects = info_handler.changesets + info_handler.nodes + info_handler.ways + info_handler.relations;
+        std::cout << "  Number of buffers: " << info_handler.buffers_count;
+        if (num_objects != 0) {
+            std::cout << " (avg " << (num_objects / info_handler.buffers_count) << " objects per buffer)\n";
+        } else {
+            std::cout << '\n';
+        }
+
+        const auto buffers_size = static_cast<double>(info_handler.buffers_size / (1000 * 1000)) / 1000; // NOLINT(bugprone-integer-division)
+        std::cout << "  Sum of buffer sizes: " << info_handler.buffers_size << " (" << buffers_size << " GB)\n";
+
+        const auto buffers_capacity= static_cast<double>(info_handler.buffers_capacity / (1000 * 1000)) / 1000; // NOLINT(bugprone-integer-division)
+
+        if (info_handler.buffers_capacity != 0) {
+            const auto fill_factor = std::round(100 * static_cast<double>(info_handler.buffers_size) / static_cast<double>(info_handler.buffers_capacity));
+            std::cout << "  Sum of buffer capacities: " << info_handler.buffers_capacity << " (" << buffers_capacity << " GB, " << fill_factor << "% full)\n";
+        } else {
+            std::cout << "  Sum of buffer capacities: 0 (0 GB)\n";
+        }
     }
 
 }; // class HumanReadableOutput
@@ -432,6 +457,16 @@ public:
         m_writer.Int64(get_largest(info_handler.largest_relation_id()));
         m_writer.EndObject();
 
+        m_writer.String("buffers");
+        m_writer.StartObject();
+        m_writer.String("count");
+        m_writer.Int64(get_largest(info_handler.buffers_count));
+        m_writer.String("size");
+        m_writer.Int64(get_largest(info_handler.buffers_size));
+        m_writer.String("capacity");
+        m_writer.Int64(get_largest(info_handler.buffers_capacity));
+        m_writer.EndObject();
+
         m_writer.String("metadata");
         m_writer.StartObject();
         m_writer.String("all_objects");
@@ -614,6 +649,19 @@ public:
             return;
         }
 
+        if (m_get_value == "data.buffers.count") {
+            std::cout << info_handler.buffers_count << "\n";
+            return;
+        }
+        if (m_get_value == "data.buffers.size") {
+            std::cout << info_handler.buffers_size << "\n";
+            return;
+        }
+        if (m_get_value == "data.buffers.capacity") {
+            std::cout << info_handler.buffers_capacity << "\n";
+            return;
+        }
+
         if (m_get_value == "metadata.all_objects.version") {
             std::cout << (info_handler.metadata_all_objects.version() ? "yes\n" : "no\n");
             return;
@@ -670,6 +718,7 @@ bool CommandFileinfo::setup(const std::vector<std::string>& arguments) {
     ("json,j", "JSON output")
     ("crc,c", "Calculate CRC")
     ("no-crc", "Do not calculate CRC")
+    ("object-type,t", po::value<std::vector<std::string>>(), "Read only objects of given type (node, way, relation, changeset)")
     ;
 
     po::options_description opts_common{add_common_options()};
@@ -695,6 +744,7 @@ bool CommandFileinfo::setup(const std::vector<std::string>& arguments) {
 
     setup_common(vm, desc);
     setup_progress(vm);
+    setup_object_type_nwrc(vm);
 
     if (vm.count("extended")) {
         m_extended = true;
@@ -743,6 +793,9 @@ bool CommandFileinfo::setup(const std::vector<std::string>& arguments) {
         "data.maxid.ways",
         "data.maxid.relations",
         "data.maxid.changesets",
+        "data.buffers.count",
+        "data.buffers.size",
+        "data.buffers.capacity",
         "metadata.all_objects.version",
         "metadata.all_objects.timestamp",
         "metadata.all_objects.changeset",
@@ -791,6 +844,7 @@ void CommandFileinfo::show_arguments() {
     show_single_input_arguments(m_vout);
 
     m_vout << "  other options:\n";
+    show_object_types(m_vout);
     m_vout << "    extended output: " << (m_extended ? "yes\n" : "no\n");
     m_vout << "    calculate CRC: " << (m_calculate_crc ? "yes\n" : "no\n");
 }
@@ -808,7 +862,7 @@ bool CommandFileinfo::run() {
     output->set_crc(m_calculate_crc);
     output->file(m_input_filename, m_input_file);
 
-    osmium::io::Reader reader{m_input_file, m_extended ? osmium::osm_entity_bits::all : osmium::osm_entity_bits::nothing};
+    osmium::io::Reader reader{m_input_file, m_extended ? osm_entity_bits() : osmium::osm_entity_bits::nothing};
     osmium::io::Header header{reader.header()};
     output->header(header);
 
@@ -817,6 +871,9 @@ bool CommandFileinfo::run() {
         osmium::ProgressBar progress_bar{reader.file_size(), display_progress()};
         while (osmium::memory::Buffer buffer = reader.read()) {
             progress_bar.update(reader.offset());
+            ++info_handler.buffers_count;
+            info_handler.buffers_size += buffer.committed();
+            info_handler.buffers_capacity += buffer.capacity();
             osmium::apply(buffer, info_handler);
         }
         progress_bar.done();
