@@ -1,9 +1,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,15 +20,10 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <cstddef>
-#include <fstream>
-#include <iostream>
-#include <stdexcept>
-#include <string>
-#include <utility>
-#include <vector>
-
-#include <boost/program_options.hpp>
+#include "command_getid.hpp"
+#include "exception.hpp"
+#include "id_file.hpp"
+#include "util.hpp"
 
 #include <osmium/index/relations_map.hpp>
 #include <osmium/io/header.hpp>
@@ -41,39 +36,17 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <osmium/util/string.hpp>
 #include <osmium/util/verbose_output.hpp>
 
-#include "command_getid.hpp"
-#include "exception.hpp"
-#include "util.hpp"
+#include <boost/program_options.hpp>
 
-void CommandGetId::parse_and_add_id(const std::string& s) {
-    auto p = osmium::string_to_object_id(s.c_str(), osmium::osm_entity_bits::nwr, m_default_item_type);
-    if (p.second < 0) {
-        throw std::runtime_error{"osmium-getid does not work with negative IDs"};
-    }
-    m_ids(p.first).set(p.second);
-}
+#include <cstddef>
+#include <fstream>
+#include <iostream>
+#include <stdexcept>
+#include <string>
+#include <utility>
+#include <vector>
 
-void CommandGetId::read_id_file(std::istream& stream) {
-    m_vout << "Reading ID file...\n";
-    for (std::string line; std::getline(stream, line); ) {
-        strip_whitespace(line);
-        const auto pos = line.find_first_of(" #");
-        if (pos != std::string::npos) {
-            line.erase(pos);
-        }
-        if (!line.empty()) {
-            parse_and_add_id(line);
-        }
-    }
-}
-
-bool CommandGetId::no_ids() const {
-    return m_ids(osmium::item_type::node).empty() &&
-           m_ids(osmium::item_type::way).empty() &&
-           m_ids(osmium::item_type::relation).empty();
-}
-
-std::size_t CommandGetId::count_ids() const {
+std::size_t CommandGetId::count_ids() const noexcept {
     return m_ids(osmium::item_type::node).size() +
            m_ids(osmium::item_type::way).size() +
            m_ids(osmium::item_type::relation).size();
@@ -121,7 +94,7 @@ bool CommandGetId::setup(const std::vector<std::string>& arguments) {
     setup_output_file(vm);
 
     if (vm.count("add-referenced")) {
-        if (m_input_filename == "-") {
+        if (m_input_filename.empty() || m_input_filename == "-") {
             throw argument_error{"Can not read OSM input from STDIN when --add-referenced/-r option is used."};
         }
         m_add_referenced_objects = true;
@@ -137,17 +110,7 @@ bool CommandGetId::setup(const std::vector<std::string>& arguments) {
     }
 
     if (vm.count("default-type")) {
-        std::string t{vm["default-type"].as<std::string>()};
-
-        if (t == "n" || t == "node") {
-            m_default_item_type = osmium::item_type::node;
-        } else if (t == "w" || t == "way") {
-            m_default_item_type = osmium::item_type::way;
-        } else if (t == "r" || t == "relation") {
-            m_default_item_type = osmium::item_type::relation;
-        } else {
-            throw argument_error{std::string{"Unknown default type '"} + t + "' (Allowed are 'node', 'way', and 'relation')."};
-        }
+        m_default_item_type = parse_item_type(vm["default-type"].as<std::string>());
     }
 
     if (vm.count("verbose-ids")) {
@@ -158,23 +121,26 @@ bool CommandGetId::setup(const std::vector<std::string>& arguments) {
     if (vm.count("id-file")) {
         for (const std::string& filename : vm["id-file"].as<std::vector<std::string>>()) {
             if (filename == "-") {
-                if (m_input_filename == "-") {
+                if (m_input_filename.empty() || m_input_filename == "-") {
                     throw argument_error{"Can not read OSM input and IDs both from STDIN."};
                 }
-                read_id_file(std::cin);
+                m_vout << "Reading IDs from STDIN...\n";
+                read_id_file(std::cin, m_ids, m_default_item_type);
             } else {
                 std::ifstream id_file{filename};
                 if (!id_file.is_open()) {
                     throw argument_error{"Could not open file '" + filename + "'"};
                 }
-                read_id_file(id_file);
+                m_vout << "Reading ID file...\n";
+                read_id_file(id_file, m_ids, m_default_item_type);
             }
         }
     }
 
     if (vm.count("id-osm-file")) {
         for (const std::string& filename : vm["id-osm-file"].as<std::vector<std::string>>()) {
-            read_id_osm_file(filename);
+            m_vout << "Reading OSM ID file...\n";
+            read_id_osm_file(filename, m_ids);
         }
     }
 
@@ -184,11 +150,11 @@ bool CommandGetId::setup(const std::vector<std::string>& arguments) {
             sids += s + " ";
         }
         for (const auto& s : osmium::split_string(sids, "\t ;,/|", true)) {
-            parse_and_add_id(s);
+            parse_and_add_id(s, m_ids, m_default_item_type);
         }
     }
 
-    if (no_ids()) {
+    if (no_ids(m_ids)) {
         throw argument_error{"Please specify IDs to look for on command line or with option --id-file/-i or --id-osm-file/-I."};
     }
 
@@ -230,31 +196,19 @@ void CommandGetId::show_arguments() {
 osmium::osm_entity_bits::type CommandGetId::get_needed_types() const {
     osmium::osm_entity_bits::type types = osmium::osm_entity_bits::nothing;
 
-    if (! m_ids(osmium::item_type::node).empty()) {
+    if (!m_ids(osmium::item_type::node).empty()) {
         types |= osmium::osm_entity_bits::node;
     }
-    if (! m_ids(osmium::item_type::way).empty()) {
+    if (!m_ids(osmium::item_type::way).empty()) {
         types |= osmium::osm_entity_bits::way;
     }
-    if (! m_ids(osmium::item_type::relation).empty()) {
+    if (!m_ids(osmium::item_type::relation).empty()) {
         types |= osmium::osm_entity_bits::relation;
     }
 
     return types;
 }
 
-void CommandGetId::add_nodes(const osmium::Way& way) {
-    for (const auto& nr : way.nodes()) {
-        m_ids(osmium::item_type::node).set(nr.positive_ref());
-    }
-}
-
-void CommandGetId::add_members(const osmium::Relation& relation) {
-    for (const auto& member : relation.members()) {
-        m_ids(member.type()).set(member.positive_ref());
-    }
-}
-
 static void print_missing_ids(const char* type, const osmium::index::IdSetDense<osmium::unsigned_object_id_type>& set) {
     if (set.empty()) {
         return;
@@ -266,22 +220,6 @@ static void print_missing_ids(const char* type, const osmium::index::IdSetDense<
     std::cerr << '\n';
 }
 
-void CommandGetId::read_id_osm_file(const std::string& file_name) {
-    m_vout << "Reading OSM ID file...\n";
-    osmium::io::Reader reader{file_name, osmium::osm_entity_bits::object};
-    while (osmium::memory::Buffer buffer = reader.read()) {
-        for (const auto& object : buffer.select<osmium::OSMObject>()) {
-            m_ids(object.type()).set(object.positive_id());
-            if (object.type() == osmium::item_type::way) {
-                add_nodes(static_cast<const osmium::Way&>(object));
-            } else if (object.type() == osmium::item_type::relation) {
-                add_members(static_cast<const osmium::Relation&>(object));
-            }
-        }
-    }
-    reader.close();
-}
-
 void CommandGetId::mark_rel_ids(const osmium::index::RelationsMapIndex& rel_in_rel, osmium::object_id_type parent_id) {
     rel_in_rel.for_each(parent_id, [&](osmium::unsigned_object_id_type member_id) {
         if (m_ids(osmium::item_type::relation).check_and_set(member_id)) {
@@ -351,7 +289,7 @@ void CommandGetId::find_nodes_in_ways() {
     while (osmium::memory::Buffer buffer = reader.read()) {
         for (const auto& way : buffer.select<osmium::Way>()) {
             if (m_ids(osmium::item_type::way).get(way.positive_id())) {
-                add_nodes(way);
+                add_nodes(way, m_ids);
             }
         }
     }
@@ -418,7 +356,7 @@ bool CommandGetId::run() {
     reader.close();
 
     if (!m_work_with_history) {
-        if (no_ids()) {
+        if (no_ids(m_ids)) {
             m_vout << "Found all objects.\n";
         } else {
             m_vout << "Did not find " << count_ids() << " object(s).\n";
@@ -434,6 +372,6 @@ bool CommandGetId::run() {
 
     m_vout << "Done.\n";
 
-    return m_work_with_history || no_ids();
+    return m_work_with_history || no_ids(m_ids);
 }
 
