@@ -28,6 +28,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <osmium/fwd.hpp>
 #include <osmium/index/id_set.hpp>
 #include <osmium/index/nwr_array.hpp>
+#include <osmium/index/relations_map.hpp>
 #include <osmium/osm/entity_bits.hpp>
 #include <osmium/osm/item_type.hpp>
 #include <osmium/osm/types.hpp>
@@ -37,24 +38,16 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <string>
 #include <vector>
 
-namespace osmium {
-
-    namespace index {
-        class RelationsMapIndex;
-    } // namespace index
-
-} // namespace osmium
-
 class CommandGetId : public Command, public with_single_osm_input, public with_osm_output {
 
+    osmium::nwr_array<osmium::index::IdSetDense<osmium::unsigned_object_id_type>> m_ids;
+
     osmium::item_type m_default_item_type = osmium::item_type::node;
 
     bool m_add_referenced_objects = false;
     bool m_work_with_history = false;
     bool m_verbose_ids = false;
 
-    osmium::nwr_array<osmium::index::IdSetDense<osmium::unsigned_object_id_type>> m_ids;
-
     osmium::osm_entity_bits::type get_needed_types() const;
     std::size_t count_ids() const noexcept;
 
