@@ -28,6 +28,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <osmium/fwd.hpp>
 #include <osmium/index/id_set.hpp>
 #include <osmium/index/nwr_array.hpp>
+#include <osmium/index/relations_map.hpp>
 #include <osmium/osm/entity_bits.hpp>
 #include <osmium/osm/item_type.hpp>
 #include <osmium/osm/types.hpp>
@@ -37,23 +38,15 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <string>
 #include <vector>
 
-namespace osmium {
-
-    namespace index {
-        class RelationsMapIndex;
-    } // namespace index
-
-} // namespace osmium
-
 class CommandGetParents : public Command, public with_single_osm_input, public with_osm_output {
 
+    osmium::nwr_array<osmium::index::IdSetDense<osmium::unsigned_object_id_type>> m_ids;
+
     osmium::item_type m_default_item_type = osmium::item_type::node;
 
     bool m_add_self = false;
     bool m_verbose_ids = false;
 
-    osmium::nwr_array<osmium::index::IdSetDense<osmium::unsigned_object_id_type>> m_ids;
-
     osmium::osm_entity_bits::type get_needed_types() const;
 
     void add_nodes(const osmium::Way& way);
