@@ -4,9 +4,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,18 +23,18 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <algorithm>
-#include <iterator>
-#include <string>
-#include <unordered_map>
-#include <vector>
+#include "cmd.hpp" // IWYU pragma: export
 
 #include <osmium/handler/check_order.hpp>
 #include <osmium/index/nwr_array.hpp>
 #include <osmium/memory/buffer.hpp>
+#include <osmium/osm/item_type.hpp>
 #include <osmium/osm/types.hpp>
 
-#include "cmd.hpp" // IWYU pragma: export
+#include <cstddef>
+#include <string>
+#include <unordered_map>
+#include <vector>
 
 /**
  * Holds the mapping from old IDs to new IDs of one object type.
@@ -61,10 +61,22 @@ class id_map {
     // in m_ids we have to take the first of potentially several identical
     // IDs we find (using std::lower_bound), its position is then the new ID.
 
+    osmium::object_id_type m_start_id = 1;
+
 public:
 
     id_map() = default;
 
+    osmium::object_id_type start_id() const noexcept {
+        return m_start_id;
+    }
+
+    void set_start_id(osmium::object_id_type start_id) noexcept {
+        m_start_id = start_id;
+    }
+
+    osmium::object_id_type add_offset_to_id(osmium::object_id_type id) const noexcept;
+
     // Map from old ID to new ID. If the old ID has been seen before, it will
     // be returned, otherwise a new ID will be allocated and stored.
     osmium::object_id_type operator()(osmium::object_id_type id);
@@ -74,6 +86,8 @@ public:
     // operation this object becomes unusable!
     void write(int fd);
 
+    void print(osmium::object_id_type new_id);
+
     // Read the mappings from a binary file into m_ids and m_extra_ids.
     void read(int fd, std::size_t file_size);
 
@@ -98,13 +112,21 @@ class CommandRenumber : public Command, public with_single_osm_input, public wit
 
     std::string filename(const char* name) const;
 
+    void set_start_ids(const std::string& str);
+
+    void read_start_ids_file();
+
     void read_index(osmium::item_type type);
 
     void write_index(osmium::item_type type);
 
+    void show_index(const std::string& type);
+
 public:
 
-    CommandRenumber() = default;
+    explicit CommandRenumber(const CommandFactory& command_factory) :
+        Command(command_factory) {
+    }
 
     bool setup(const std::vector<std::string>& arguments) override final;
 
