@@ -1,9 +1,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,28 +20,30 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <cerrno>
-#include <cstdlib>
-#include <string>
-#include <system_error>
-#include <vector>
-#include <utility>
-
-#ifndef _MSC_VER
-# include <signal.h>
-# include <unistd.h>
-#endif
-
-#include <boost/program_options.hpp>
+#include "command_show.hpp"
+#include "exception.hpp"
+#include "util.hpp"
 
 #include <osmium/io/file.hpp>
 #include <osmium/io/header.hpp>
 #include <osmium/io/reader.hpp>
 #include <osmium/io/writer.hpp>
+#include <osmium/memory/buffer.hpp>
+#include <osmium/util/verbose_output.hpp>
 
-#include "command_show.hpp"
-#include "exception.hpp"
-#include "util.hpp"
+#include <boost/program_options.hpp>
+
+#include <cerrno>
+#include <csignal>
+#include <cstdlib>
+#include <string>
+#include <system_error>
+#include <utility>
+#include <vector>
+
+#ifndef _MSC_VER
+# include <unistd.h>
+#endif
 
 #ifndef _MSC_VER
 void CommandShow::setup_pager_from_env() noexcept {
@@ -140,7 +142,7 @@ void CommandShow::show_arguments() {
     m_vout << "  other options:\n";
     m_vout << "    file format: " << m_output_format << "\n";
     m_vout << "    use color: " << yes_no(m_color_output);
-    m_vout << "    use pager: " << (m_pager == "" ? "(no pager)" : m_pager) << "\n";
+    m_vout << "    use pager: " << (m_pager.empty() ? "(no pager)" : m_pager) << "\n";
     show_object_types(m_vout);
 }
 
@@ -179,7 +181,7 @@ static int execute_pager(const std::string& pager, bool with_color) {
     // parent
     ::close(pipefd[0]); // close read end of the pipe
 
-    if (signal(SIGPIPE, SIG_IGN) == SIG_ERR) {
+    if (signal(SIGPIPE, SIG_IGN) == SIG_ERR) { // NOLINT(cppcoreguidelines-pro-type-cstyle-cast)
         throw std::system_error{errno, std::system_category(), "Could not run pager: signal() call failed"};
     }
 
@@ -227,7 +229,7 @@ bool CommandShow::run() {
         if (pid < 0) {
             throw std::system_error{errno, std::system_category(), "Could not run pager: wait() call failed"};
         }
-        if (WIFEXITED(status) && WEXITSTATUS(status) == 1) {
+        if (WIFEXITED(status) && WEXITSTATUS(status) == 1) { // NOLINT(hicpp-signed-bitwise)
             throw argument_error{std::string{"Could not run pager '"} + m_pager + "'"};
         }
 #endif
