@@ -4,9 +4,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,22 +23,24 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
+#include "cmd.hpp" // IWYU pragma: export
+
 #include <string>
 #include <vector>
 
-#include "cmd.hpp" // IWYU pragma: export
-
 class CommandShow : public Command, public with_single_osm_input {
 
     std::string m_output_format{"debug,color=true"};
     std::string m_pager;
-    bool m_color_output;
+    bool m_color_output = false;
 
     void setup_pager_from_env() noexcept;
 
 public:
 
-    CommandShow() = default;
+    explicit CommandShow(const CommandFactory& command_factory) :
+        Command(command_factory) {
+    }
 
     bool setup(const std::vector<std::string>& arguments) override final;
 
