@@ -89,6 +89,7 @@ bool CommandTagsFilter::setup(const std::vector<std::string>& arguments) {
     ("expressions,e", po::value<std::string>(), "Read filter expressions from file")
     ("invert-match,i", "Invert the sense of matching, exclude objects with matching tags")
     ("omit-referenced,R", "Omit referenced objects")
+    ("remove-tags,t", "Remove tags from non-matching objects")
     ;
 
     po::options_description opts_common{add_common_options()};
@@ -130,6 +131,10 @@ bool CommandTagsFilter::setup(const std::vector<std::string>& arguments) {
         m_invert_match = true;
     }
 
+    if (vm.count("remove-tags")) {
+        m_remove_tags = true;
+    }
+
     if (vm.count("expression-list")) {
         for (const auto& e : vm["expression-list"].as<std::vector<std::string>>()) {
             parse_and_add_expression(e);
@@ -156,15 +161,19 @@ void CommandTagsFilter::show_arguments() {
 }
 
 osmium::osm_entity_bits::type CommandTagsFilter::get_needed_types() const {
+    if (m_invert_match) {
+        return osmium::osm_entity_bits::nwr;
+    }
+
     osmium::osm_entity_bits::type types = osmium::osm_entity_bits::nothing;
 
-    if (!m_ids(osmium::item_type::node).empty() || !m_filters(osmium::item_type::node).empty()) {
+    if (!m_referenced_ids(osmium::item_type::node).empty() || !m_filters(osmium::item_type::node).empty()) {
         types |= osmium::osm_entity_bits::node;
     }
-    if (!m_ids(osmium::item_type::way).empty() || !m_filters(osmium::item_type::way).empty() || !m_area_filters.empty()) {
+    if (!m_referenced_ids(osmium::item_type::way).empty() || !m_filters(osmium::item_type::way).empty() || !m_area_filters.empty()) {
         types |= osmium::osm_entity_bits::way;
     }
-    if (!m_ids(osmium::item_type::relation).empty() || !m_filters(osmium::item_type::relation).empty() || !m_area_filters.empty()) {
+    if (!m_referenced_ids(osmium::item_type::relation).empty() || !m_filters(osmium::item_type::relation).empty() || !m_area_filters.empty()) {
         types |= osmium::osm_entity_bits::relation;
     }
 
@@ -173,13 +182,13 @@ osmium::osm_entity_bits::type CommandTagsFilter::get_needed_types() const {
 
 void CommandTagsFilter::add_nodes(const osmium::Way& way) {
     for (const auto& nr : way.nodes()) {
-        m_ids(osmium::item_type::node).set(nr.positive_ref());
+        m_referenced_ids(osmium::item_type::node).set(nr.positive_ref());
     }
 }
 
 void CommandTagsFilter::add_members(const osmium::Relation& relation) {
     for (const auto& member : relation.members()) {
-        m_ids(member.type()).set(member.positive_ref());
+        m_referenced_ids(member.type()).set(member.positive_ref());
     }
 }
 
@@ -225,7 +234,7 @@ bool CommandTagsFilter::matches_object(const osmium::OSMObject& object) const no
 
 void CommandTagsFilter::mark_rel_ids(const osmium::index::RelationsMapIndex& rel_in_rel, osmium::object_id_type parent_id) {
     rel_in_rel.for_each(parent_id, [&](osmium::unsigned_object_id_type member_id) {
-        if (m_ids(osmium::item_type::relation).check_and_set(member_id)) {
+        if (m_referenced_ids(osmium::item_type::relation).check_and_set(member_id)) {
             mark_rel_ids(rel_in_rel, member_id);
         }
     });
@@ -235,12 +244,20 @@ bool CommandTagsFilter::find_relations_in_relations() {
     m_vout << "  Reading input file to find relations in relations...\n";
     osmium::index::RelationsMapStash stash;
 
+    ++m_count_passes;
     osmium::io::Reader reader{m_input_file, osmium::osm_entity_bits::relation};
     while (osmium::memory::Buffer buffer = reader.read()) {
         for (const auto& relation : buffer.select<osmium::Relation>()) {
             stash.add_members(relation);
             if (matches_relation(relation) != m_invert_match) {
-                m_ids(osmium::item_type::relation).set(relation.positive_id());
+                m_matching_ids(osmium::item_type::relation).set(relation.positive_id());
+                for (const auto& member : relation.members()) {
+                    if (member.type() == osmium::item_type::node) {
+                        m_referenced_ids(osmium::item_type::node).set(member.positive_ref());
+                    } else if (member.type() == osmium::item_type::way) {
+                        m_referenced_ids(osmium::item_type::way).set(member.positive_ref());
+                    }
+                }
             }
         }
     }
@@ -251,7 +268,7 @@ bool CommandTagsFilter::find_relations_in_relations() {
     }
 
     const auto rel_in_rel = stash.build_parent_to_member_index();
-    for (const osmium::unsigned_object_id_type id : m_ids(osmium::item_type::relation)) {
+    for (const osmium::unsigned_object_id_type id : m_referenced_ids(osmium::item_type::relation)) {
         mark_rel_ids(rel_in_rel, id);
     }
 
@@ -261,15 +278,16 @@ bool CommandTagsFilter::find_relations_in_relations() {
 void CommandTagsFilter::find_nodes_and_ways_in_relations() {
     m_vout << "  Reading input file to find nodes/ways in relations...\n";
 
+    ++m_count_passes;
     osmium::io::Reader reader{m_input_file, osmium::osm_entity_bits::relation};
     while (osmium::memory::Buffer buffer = reader.read()) {
         for (const auto& relation : buffer.select<osmium::Relation>()) {
-            if (m_ids(osmium::item_type::relation).get(relation.positive_id())) {
+            if (m_referenced_ids(osmium::item_type::relation).get(relation.positive_id())) {
                 for (const auto& member : relation.members()) {
                     if (member.type() == osmium::item_type::node) {
-                        m_ids(osmium::item_type::node).set(member.positive_ref());
+                        m_referenced_ids(osmium::item_type::node).set(member.positive_ref());
                     } else if (member.type() == osmium::item_type::way) {
-                        m_ids(osmium::item_type::way).set(member.positive_ref());
+                        m_referenced_ids(osmium::item_type::way).set(member.positive_ref());
                     }
                 }
             }
@@ -281,13 +299,14 @@ void CommandTagsFilter::find_nodes_and_ways_in_relations() {
 void CommandTagsFilter::find_nodes_in_ways() {
     m_vout << "  Reading input file to find nodes in ways...\n";
 
+    ++m_count_passes;
     osmium::io::Reader reader{m_input_file, osmium::osm_entity_bits::way};
     while (osmium::memory::Buffer buffer = reader.read()) {
         for (const auto& way : buffer.select<osmium::Way>()) {
-            if (m_ids(osmium::item_type::way).get(way.positive_id())) {
+            if (m_referenced_ids(osmium::item_type::way).get(way.positive_id())) {
                 add_nodes(way);
             } else if (matches_way(way) != m_invert_match) {
-                m_ids(osmium::item_type::way).set(way.positive_id());
+                m_matching_ids(osmium::item_type::way).set(way.positive_id());
                 add_nodes(way);
             }
         }
@@ -297,7 +316,7 @@ void CommandTagsFilter::find_nodes_in_ways() {
 
 void CommandTagsFilter::find_referenced_objects() {
     m_vout << "Following references...\n";
-    bool todo = !m_filters(osmium::item_type::relation).empty() || !m_area_filters.empty();
+    bool todo = !m_filters(osmium::item_type::relation).empty() || !m_area_filters.empty() || m_invert_match;
     if (todo) {
         todo = find_relations_in_relations();
     }
@@ -306,7 +325,7 @@ void CommandTagsFilter::find_referenced_objects() {
         find_nodes_and_ways_in_relations();
     }
 
-    if (!m_ids(osmium::item_type::way).empty() || !m_filters(osmium::item_type::way).empty() || !m_area_filters.empty()) {
+    if (!m_referenced_ids(osmium::item_type::way).empty() || !m_filters(osmium::item_type::way).empty() || !m_area_filters.empty()) {
         find_nodes_in_ways();
     }
     m_vout << "Done following references.\n";
@@ -318,6 +337,7 @@ bool CommandTagsFilter::run() {
     }
 
     m_vout << "Opening input file...\n";
+    ++m_count_passes;
     osmium::io::Reader reader{m_input_file, get_needed_types()};
 
     m_vout << "Opening output file...\n";
@@ -330,13 +350,16 @@ bool CommandTagsFilter::run() {
     osmium::ProgressBar progress_bar{reader.file_size(), display_progress()};
     while (osmium::memory::Buffer buffer = reader.read()) {
         progress_bar.update(reader.offset());
-        for (const auto& object : buffer.select<osmium::OSMObject>()) {
-            if (m_ids(object.type()).get(object.positive_id())) {
+        for (auto& object : buffer.select<osmium::OSMObject>()) {
+            if (m_matching_ids(object.type()).get(object.positive_id())) {
                 writer(object);
-            } else if (!m_add_referenced_objects || object.type() == osmium::item_type::node) {
-                if (matches_object(object) != m_invert_match) {
-                    writer(object);
+            } else if ((!m_add_referenced_objects || object.type() == osmium::item_type::node) && matches_object(object) != m_invert_match) {
+                writer(object);
+            } else if (m_referenced_ids(object.type()).get(object.positive_id())) {
+                if (m_remove_tags) {
+                    object.remove_tags();
                 }
+                writer(object);
             }
         }
     }
@@ -350,6 +373,7 @@ bool CommandTagsFilter::run() {
 
     show_memory_used();
 
+    m_vout << "Needed " << m_count_passes << " passes through the input file.\n";
     m_vout << "Done.\n";
 
     return true;
