@@ -28,6 +28,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <osmium/fwd.hpp>
 #include <osmium/index/id_set.hpp>
 #include <osmium/index/nwr_array.hpp>
+#include <osmium/index/relations_map.hpp>
 #include <osmium/osm/entity_bits.hpp>
 #include <osmium/osm/item_type.hpp>
 #include <osmium/osm/types.hpp>
@@ -36,23 +37,18 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <string>
 #include <vector>
 
-namespace osmium {
-
-    namespace index {
-        class RelationsMapIndex;
-    } // namespace index
-
-} // namespace osmium
-
 class CommandTagsFilter : public Command, public with_single_osm_input, public with_osm_output {
 
-    bool m_add_referenced_objects = true;
-    bool m_invert_match = false;
-
     osmium::nwr_array<osmium::TagsFilter> m_filters;
     osmium::TagsFilter m_area_filters;
 
-    osmium::nwr_array<osmium::index::IdSetDense<osmium::unsigned_object_id_type>> m_ids;
+    osmium::nwr_array<osmium::index::IdSetDense<osmium::unsigned_object_id_type>> m_matching_ids;
+    osmium::nwr_array<osmium::index::IdSetDense<osmium::unsigned_object_id_type>> m_referenced_ids;
+
+    int m_count_passes = 0;
+    bool m_add_referenced_objects = true;
+    bool m_invert_match = false;
+    bool m_remove_tags = false;
 
     osmium::osm_entity_bits::type get_needed_types() const;
 
