@@ -1,9 +1,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,20 +20,16 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <algorithm>
-#include <ctime>
-#include <stdexcept>
-#include <string>
-#include <vector>
-
-#include <boost/program_options.hpp>
+#include "command_time_filter.hpp"
+#include "exception.hpp"
+#include "util.hpp"
 
 #include <osmium/diff_iterator.hpp>
 #include <osmium/io/file.hpp>
 #include <osmium/io/header.hpp>
 #include <osmium/io/input_iterator.hpp>
 #include <osmium/io/output_iterator.hpp>
-#include <osmium/io/reader.hpp>
+#include <osmium/io/reader_with_progress_bar.hpp>
 #include <osmium/io/writer.hpp>
 #include <osmium/osm/diff_object.hpp>
 #include <osmium/osm/entity_bits.hpp>
@@ -41,9 +37,13 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <osmium/osm/timestamp.hpp>
 #include <osmium/util/verbose_output.hpp>
 
-#include "command_time_filter.hpp"
-#include "exception.hpp"
-#include "util.hpp"
+#include <boost/program_options.hpp>
+
+#include <algorithm>
+#include <ctime>
+#include <stdexcept>
+#include <string>
+#include <vector>
 
 bool CommandTimeFilter::setup(const std::vector<std::string>& arguments) {
     po::options_description opts_common{add_common_options()};
@@ -73,10 +73,11 @@ bool CommandTimeFilter::setup(const std::vector<std::string>& arguments) {
     po::notify(vm);
 
     setup_common(vm, desc);
+    setup_progress(vm);
     setup_input_file(vm);
     setup_output_file(vm);
 
-    m_from = osmium::Timestamp(std::time(0));
+    m_from = osmium::Timestamp{std::time(nullptr)};
     m_to = m_from;
 
     if (vm.count("time-from")) {
@@ -126,7 +127,7 @@ void CommandTimeFilter::show_arguments() {
 
 bool CommandTimeFilter::run() {
     m_vout << "Opening input file...\n";
-    osmium::io::Reader reader{m_input_file, osmium::osm_entity_bits::object};
+    osmium::io::ReaderWithProgressBar reader{display_progress(), m_input_file, osmium::osm_entity_bits::object};
 
     m_vout << "Opening output file...\n";
     osmium::io::Header header{reader.header()};
