@@ -4,9 +4,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,12 +23,12 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <string>
-#include <vector>
+#include "cmd.hpp" // IWYU pragma: export
 
 #include <osmium/osm/timestamp.hpp>
 
-#include "cmd.hpp" // IWYU pragma: export
+#include <string>
+#include <vector>
 
 class CommandTimeFilter : public Command, public with_single_osm_input, public with_osm_output {
 
@@ -37,7 +37,9 @@ class CommandTimeFilter : public Command, public with_single_osm_input, public w
 
 public:
 
-    CommandTimeFilter() = default;
+    explicit CommandTimeFilter(const CommandFactory& command_factory) :
+        Command(command_factory) {
+    }
 
     bool setup(const std::vector<std::string>& arguments) override final;
 
