@@ -1,12 +1,12 @@
-#ifndef EXPORT_TEXT_HANDLER
-#define EXPORT_TEXT_HANDLER
+#ifndef EXPORT_EXPORT_FORMAT_TEXT_HPP
+#define EXPORT_EXPORT_FORMAT_TEXT_HPP
 
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,19 +23,19 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <string>
+#include "export_format.hpp"
 
 #include <osmium/fwd.hpp>
 #include <osmium/geom/wkt.hpp>
 #include <osmium/io/writer_options.hpp>
 
-#include "export_format.hpp"
+#include <string>
 
 class ExportFormatText : public ExportFormat {
 
     osmium::geom::WKTFactory<> m_factory;
     std::string m_buffer;
-    std::size_t m_commit_size;
+    std::size_t m_commit_size = 0;
     int m_fd;
     osmium::io::fsync m_fsync;
 
@@ -43,7 +43,6 @@ class ExportFormatText : public ExportFormat {
 
     void start_feature(char type, osmium::object_id_type id);
     void add_attributes(const osmium::OSMObject& object);
-    bool add_tags(const osmium::OSMObject& object);
     void finish_feature(const osmium::OSMObject& object);
 
 public:
@@ -68,4 +67,4 @@ public:
 
 }; // class ExportFormatText
 
-#endif // EXPORT_TEXT_HANDLER
+#endif // EXPORT_EXPORT_FORMAT_TEXT_HPP
