@@ -4,9 +4,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,10 +23,10 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <string>
-
 #include <osmium/tags/tags_filter.hpp>
 
+#include <string>
+
 enum class unique_id_type {
     none    = 0,
     counter = 1,
@@ -50,4 +50,22 @@ struct options_type {
     bool print_record_separator = true;
 };
 
+struct geometry_types {
+
+    bool point = true;
+    bool linestring = true;
+    bool polygon = true;
+
+    void clear() noexcept {
+        point = false;
+        linestring = false;
+        polygon = false;
+    }
+
+    bool empty() const noexcept {
+        return !point && !linestring && !polygon;
+    }
+
+}; // struct geometry_types
+
 #endif // EXPORT_OPTIONS_HPP
