@@ -1,9 +1,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,21 +20,24 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <sstream>
-#include <string>
+#include "extract.hpp"
 
 #include <osmium/io/writer_options.hpp>
 
-#include "extract.hpp"
+#include <sstream>
+#include <string>
 
 namespace osmium {
+
     namespace io {
         class Header;
-    }
+    } // namespace io
+
     namespace memory {
         class Item;
-    }
-}
+    } // namespace memory
+
+} // namespace osmium
 
 void Extract::open_file(const osmium::io::Header& header, osmium::io::overwrite output_overwrite, osmium::io::fsync sync) {
     m_writer.reset(new osmium::io::Writer{m_output_file, header, output_overwrite, sync});
