@@ -4,9 +4,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,28 +23,30 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <memory>
-#include <string>
-#include <utility>
-#include <vector>
-
 #include <osmium/osm/box.hpp>
 #include <osmium/io/file.hpp>
 #include <osmium/io/writer_options.hpp>
 #include <osmium/io/writer.hpp>
 
+#include <memory>
+#include <string>
+#include <utility>
+#include <vector>
+
 namespace osmium {
+
     class Box;
     class Location;
 
     namespace io {
         class Header;
-    }
+    } // namespace io
 
     namespace memory {
         class Item;
-    }
-}
+    } // namespace memory
+
+} // namespace osmium
 
 class Extract {
 
