@@ -1,9 +1,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,29 +20,32 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
+#include "extract_polygon.hpp"
+#include "../exception.hpp"
+
+#include <osmium/geom/wkt.hpp>
+#include <osmium/osm/location.hpp>
+#include <osmium/osm/segment.hpp>
+
 #include <algorithm>
-#include <cassert>
 #include <cstddef>
 #include <cstdint>
 #include <string>
 #include <utility>
 #include <vector>
 
-#include <osmium/geom/wkt.hpp>
-#include <osmium/osm/location.hpp>
-#include <osmium/osm/segment.hpp>
-
-#include "extract_polygon.hpp"
-
 static void add_ring(std::vector<osmium::Segment>& segments, const osmium::NodeRefList& ring) {
     auto it = ring.begin();
     const auto end = ring.end();
 
-    assert(it != end);
-    auto last_it = it++;
+    if (it == end) {
+        throw config_error{"Ring without any points."};
+    }
+
+    auto prev_it = it++;
     while (it != end) {
-        segments.emplace_back(last_it->location(), it->location());
-        last_it = it++;
+        segments.emplace_back(prev_it->location(), it->location());
+        prev_it = it++;
     }
 }
 
@@ -53,9 +56,7 @@ const osmium::Area& ExtractPolygon::area() const noexcept {
 ExtractPolygon::ExtractPolygon(const osmium::io::File& output_file, const std::string& description, const osmium::memory::Buffer& buffer, std::size_t offset) :
     Extract(output_file, description, buffer.get<osmium::Area>(offset).envelope()),
     m_buffer(buffer),
-    m_offset(offset),
-    m_bands(),
-    m_dy(0) {
+    m_offset(offset) {
 
     // get segments from all rings
     std::vector<osmium::Segment> segments;
@@ -117,7 +118,7 @@ ExtractPolygon::ExtractPolygon(const osmium::io::File& output_file, const std::s
 */
 
 bool ExtractPolygon::contains(const osmium::Location& location) const noexcept {
-    if (!location.valid() || ! envelope().contains(location)) {
+    if (!location.valid() || !envelope().contains(location)) {
         return false;
     }
 
