@@ -4,9 +4,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,14 +23,16 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <vector>
-
 #include "extract.hpp"
 
 namespace osmium {
+
     class Area;
     class Segment;
-}
+
+} // namespace osmium
+
+#include <vector>
 
 class ExtractPolygon : public Extract {
 
@@ -38,7 +40,7 @@ class ExtractPolygon : public Extract {
     std::size_t m_offset;
 
     std::vector<std::vector<osmium::Segment>> m_bands;
-    int32_t m_dy;
+    int32_t m_dy = 0;
 
     const osmium::Area& area() const noexcept;
 
