@@ -1,9 +1,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,22 +20,22 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <cassert>
-#include <fstream>
-#include <string>
-#include <vector>
-
-#include <rapidjson/document.h>
-#include <rapidjson/error/en.h>
-#include <rapidjson/istreamwrapper.h>
+#include "../exception.hpp"
+#include "geojson_file_parser.hpp"
 
 #include <osmium/builder/osm_object_builder.hpp>
 #include <osmium/geom/coordinates.hpp>
 #include <osmium/memory/buffer.hpp>
 #include <osmium/osm/location.hpp>
 
-#include "../exception.hpp"
-#include "geojson_file_parser.hpp"
+#include <rapidjson/document.h>
+#include <rapidjson/error/en.h>
+#include <rapidjson/istreamwrapper.h>
+
+#include <cassert>
+#include <fstream>
+#include <string>
+#include <vector>
 
 std::string get_value_as_string(const rapidjson::Value& object, const char* key) {
     assert(object.IsObject());
@@ -47,9 +47,9 @@ std::string get_value_as_string(const rapidjson::Value& object, const char* key)
 
     if (it->value.IsString()) {
         return it->value.GetString();
-    } else {
-        throw config_error{std::string{"Value for name '"} + key + "' must be a string."};
     }
+
+    throw config_error{std::string{"Value for name '"} + key + "' must be a string."};
 }
 
 // parse coordinate pair from JSON array
@@ -92,7 +92,7 @@ std::vector<osmium::geom::Coordinates> parse_ring(const rapidjson::Value& value)
 void parse_rings(const rapidjson::Value& value, osmium::builder::AreaBuilder& builder) {
     assert(value.IsArray());
     const auto array = value.GetArray();
-    if (array.Size() < 1) {
+    if (array.Empty()) {
         throw config_error{"Polygon must contain at least one ring."};
     }
 
@@ -125,7 +125,7 @@ std::size_t parse_polygon_array(const rapidjson::Value& value, osmium::memory::B
 std::size_t parse_multipolygon_array(const rapidjson::Value& value, osmium::memory::Buffer& buffer) {
     assert(value.IsArray());
     const auto array = value.GetArray();
-    if (array.Size() < 1) {
+    if (array.Empty()) {
         throw config_error{"Multipolygon must contain at least one polygon array."};
     }
 
@@ -142,45 +142,22 @@ std::size_t parse_multipolygon_array(const rapidjson::Value& value, osmium::memo
     return buffer.commit();
 }
 
-void GeoJSONFileParser::error(const std::string& message) {
+OSMIUM_NORETURN void GeoJSONFileParser::error(const std::string& message) {
     throw geojson_error{std::string{"In file '"} + m_file_name + "':\n" + message};
 }
 
-GeoJSONFileParser::GeoJSONFileParser(osmium::memory::Buffer& buffer, const std::string& file_name) :
+GeoJSONFileParser::GeoJSONFileParser(osmium::memory::Buffer& buffer, std::string file_name) :
     m_buffer(buffer),
-    m_file_name(file_name),
+    m_file_name(std::move(file_name)),
     m_file(m_file_name) {
     if (!m_file.is_open()) {
         throw config_error{std::string{"Could not open file '"} + m_file_name + "'."};
     }
 }
 
-std::size_t GeoJSONFileParser::operator()() {
-    rapidjson::IStreamWrapper stream_wrapper{m_file};
-
-    rapidjson::Document doc;
-    if (doc.ParseStream<rapidjson::kParseCommentsFlag | rapidjson::kParseTrailingCommasFlag>(stream_wrapper).HasParseError()) {
-        error(std::string{"JSON error at offset "} +
-              std::to_string(doc.GetErrorOffset()) +
-              " : " +
-              rapidjson::GetParseError_En(doc.GetParseError()));
-    }
-
-    if (!doc.IsObject()) {
-        error("Top-level value must be an object.");
-    }
-
-    const std::string type{get_value_as_string(doc, "type")};
-    if (type.empty()) {
-        error("Expected 'type' name with the value 'Feature'.");
-    }
-
-    if (type != "Feature") {
-        error("Expected 'type' value to be 'Feature'.");
-    }
-
-    const auto json_geometry = doc.FindMember("geometry");
-    if (json_geometry == doc.MemberEnd()) {
+std::size_t GeoJSONFileParser::parse_top(const rapidjson::Value& top) {
+    const auto json_geometry = top.FindMember("geometry");
+    if (json_geometry == top.MemberEnd()) {
         error("Missing 'geometry' name.");
     }
 
@@ -207,8 +184,64 @@ std::size_t GeoJSONFileParser::operator()() {
 
     if (geometry_type == "Polygon") {
         return parse_polygon_array(json_coordinates->value, m_buffer);
-    } else {
-        return parse_multipolygon_array(json_coordinates->value, m_buffer);
     }
+
+    return parse_multipolygon_array(json_coordinates->value, m_buffer);
+}
+
+std::size_t GeoJSONFileParser::operator()() {
+    rapidjson::IStreamWrapper stream_wrapper{m_file};
+
+    rapidjson::Document doc;
+    if (doc.ParseStream<rapidjson::kParseCommentsFlag | rapidjson::kParseTrailingCommasFlag>(stream_wrapper).HasParseError()) {
+        error(std::string{"JSON error at offset "} +
+              std::to_string(doc.GetErrorOffset()) +
+              " : " +
+              rapidjson::GetParseError_En(doc.GetParseError()));
+    }
+
+    if (!doc.IsObject()) {
+        error("Top-level value must be an object.");
+    }
+
+    const std::string type{get_value_as_string(doc, "type")};
+    if (type.empty()) {
+        error("Expected 'type' name with the value 'Feature' or 'FeatureCollection'.");
+    }
+
+    if (type == "Feature") {
+        return parse_top(doc);
+    }
+
+    if (type == "FeatureCollection") {
+        const auto json_features = doc.FindMember("features");
+        if (json_features == doc.MemberEnd()) {
+            error("Missing 'features' name.");
+        }
+
+        if (!json_features->value.IsArray()) {
+            error("Expected 'features' value to be an array.");
+        }
+
+        const auto json_features_array = json_features->value.GetArray();
+        if (json_features_array.Empty()) {
+            throw config_error{"Features array must contain at least one polygon."};
+        }
+
+        const auto& json_first_feature = json_features_array[0];
+        if (!json_first_feature.IsObject()) {
+            error("Expected values of 'features' array to be a objects.");
+        }
+
+        const std::string feature_type{get_value_as_string(json_first_feature, "type")};
+
+        if (feature_type != "Feature") {
+            error("Expected 'type' value to be 'Feature'.");
+        }
+
+        return parse_top(json_first_feature);
+    }
+
+    error("Expected 'type' value to be 'Feature'.");
 }
 
