@@ -1,9 +1,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,8 +20,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <cstddef>
-#include <string>
+#include "osm_file_parser.hpp"
 
 #include <osmium/area/assembler.hpp>
 #include <osmium/area/multipolygon_collector.hpp>
@@ -32,14 +31,15 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <osmium/io/file.hpp>
 #include <osmium/memory/buffer.hpp>
 
-#include "osm_file_parser.hpp"
+#include <cstddef>
+#include <string>
 
 using index_type = osmium::index::map::SparseMemArray<osmium::unsigned_object_id_type, osmium::Location>;
 using location_handler_type = osmium::handler::NodeLocationsForWays<index_type>;
 
-OSMFileParser::OSMFileParser(osmium::memory::Buffer& buffer, const std::string& file_name) :
+OSMFileParser::OSMFileParser(osmium::memory::Buffer& buffer, std::string file_name) :
     m_buffer(buffer),
-    m_file_name(file_name) {
+    m_file_name(std::move(file_name)) {
 }
 
 std::size_t OSMFileParser::operator()() {
