@@ -4,9 +4,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,11 +23,15 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <string>
+namespace osmium {
 
-namespace osmium { namespace memory {
-    class Buffer;
-}}
+    namespace memory {
+        class Buffer;
+    } // namespace memory
+
+} // namespace osmium
+
+#include <string>
 
 /**
  * Gets areas from OSM files.
@@ -39,7 +43,7 @@ class OSMFileParser {
 
 public:
 
-    OSMFileParser(osmium::memory::Buffer& buffer, const std::string& file_name);
+    OSMFileParser(osmium::memory::Buffer& buffer, std::string file_name);
 
     std::size_t operator()();
 
