@@ -1,9 +1,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,27 +20,26 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <fstream>
-#include <sstream>
-#include <string>
-#include <vector>
+#include "../exception.hpp"
+#include "poly_file_parser.hpp"
 
 #include <osmium/geom/coordinates.hpp>
 #include <osmium/memory/buffer.hpp>
 #include <osmium/util/string.hpp>
 
-#include "../exception.hpp"
-#include "poly_file_parser.hpp"
+#include <fstream>
+#include <sstream>
+#include <string>
+#include <vector>
 
-void PolyFileParser::error(const std::string& message) {
+OSMIUM_NORETURN void PolyFileParser::error(const std::string& message) {
     throw poly_error{std::string{"In file '"} + m_file_name + "' on line " + std::to_string(m_line + 1) + ":\n" + message};
 }
 
 PolyFileParser::PolyFileParser(osmium::memory::Buffer& buffer, const std::string& file_name) :
     m_buffer(buffer),
     m_builder(nullptr),
-    m_file_name(file_name),
-    m_data() {
+    m_file_name(file_name) {
     std::ifstream file{file_name};
     if (!file.is_open()) {
         throw config_error{std::string{"Could not open file '"} + file_name + "'"};
