@@ -4,9 +4,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,16 +23,21 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
+#include <osmium/builder/osm_object_builder.hpp>
+#include <osmium/util/compatibility.hpp>
+
+namespace osmium {
+
+    namespace memory {
+        class Buffer;
+    } // namespace memory
+
+} // namespace osmium
+
 #include <memory>
 #include <string>
 #include <vector>
 
-#include <osmium/builder/osm_object_builder.hpp>
-
-namespace osmium { namespace memory {
-    class Buffer;
-}}
-
 /**
  *  Thrown when there is a problem with parsing a poly file.
  */
@@ -48,7 +53,7 @@ struct poly_error : public std::runtime_error {
  * Gets areas from .poly files.
  *
  * Format description:
- * http://wiki.openstreetmap.org/wiki/Osmosis/Polygon_Filter_File_Format
+ * https://wiki.openstreetmap.org/wiki/Osmosis/Polygon_Filter_File_Format
  */
 class PolyFileParser {
 
@@ -65,7 +70,7 @@ class PolyFileParser {
         return m_data[m_line];
     }
 
-    void error(const std::string& message);
+    OSMIUM_NORETURN void error(const std::string& message);
 
 public:
 
