@@ -4,9 +4,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <memory>
+#include "extract.hpp"
 
 #include <osmium/io/file.hpp>
 #include <osmium/io/reader.hpp>
@@ -38,7 +38,7 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #include <osmium/util/progress_bar.hpp>
 #include <osmium/util/verbose_output.hpp>
 
-#include "extract.hpp"
+#include <memory>
 
 template <typename T>
 class ExtractData : public T {
@@ -77,10 +77,10 @@ public:
 
     virtual const char* name() const noexcept = 0;
 
-    virtual void show_arguments(osmium::util::VerboseOutput& /*vout*/) {
+    virtual void show_arguments(osmium::VerboseOutput& /*vout*/) {
     }
 
-    virtual void run(osmium::util::VerboseOutput& vout, bool display_progress, const osmium::io::File& input_file) = 0;
+    virtual void run(osmium::VerboseOutput& vout, bool display_progress, const osmium::io::File& input_file) = 0;
 
 }; // class ExtractStrategy
 
