@@ -1,9 +1,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,24 +20,23 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
+#include "strategy_complete_ways_with_history.hpp"
+
 #include <memory>
 #include <vector>
 
-#include "strategy_complete_ways_with_history.hpp"
-
 namespace strategy_complete_ways_with_history {
 
     void Data::add_relation_parents(osmium::unsigned_object_id_type id, const osmium::index::RelationsMapIndex& map) {
         map.for_each_parent(id, [&](osmium::unsigned_object_id_type parent_id) {
-            if (! relation_ids.get(parent_id)) {
+            if (!relation_ids.get(parent_id)) {
                 relation_ids.set(parent_id);
                 add_relation_parents(parent_id, map);
             }
         });
     }
 
-    Strategy::Strategy(const std::vector<std::unique_ptr<Extract>>& extracts, const osmium::util::Options& /*options*/) :
-        ExtractStrategy() {
+    Strategy::Strategy(const std::vector<std::unique_ptr<Extract>>& extracts, const osmium::Options& /*options*/) {
         m_extracts.reserve(extracts.size());
         for (const auto& extract : extracts) {
             m_extracts.emplace_back(*extract);
@@ -56,7 +55,7 @@ namespace strategy_complete_ways_with_history {
 
     public:
 
-        Pass1(Strategy& strategy) :
+        explicit Pass1(Strategy& strategy) :
             Pass(strategy) {
         }
 
@@ -132,7 +131,7 @@ namespace strategy_complete_ways_with_history {
 
     public:
 
-        Pass2(Strategy& strategy) :
+        explicit Pass2(Strategy& strategy) :
             Pass(strategy) {
         }
 
@@ -157,12 +156,16 @@ namespace strategy_complete_ways_with_history {
 
     }; // class Pass2
 
-    void Strategy::run(osmium::util::VerboseOutput& vout, bool display_progress, const osmium::io::File& input_file) {
+    void Strategy::run(osmium::VerboseOutput& vout, bool display_progress, const osmium::io::File& input_file) {
+        if (input_file.filename().empty()) {
+            throw osmium::io_error{"Can not read from STDIN when using 'complete_ways' strategy."};
+        }
+
         vout << "Running 'complete_ways' strategy in two passes...\n";
-        const std::size_t file_size = osmium::util::file_size(input_file.filename());
+        const std::size_t file_size = osmium::file_size(input_file.filename());
         osmium::ProgressBar progress_bar{file_size * 2, display_progress};
 
-        vout << "First pass...\n";
+        vout << "First pass (of two)...\n";
         Pass1 pass1{*this};
         pass1.run(progress_bar, input_file, osmium::io::read_meta::no);
         progress_bar.file_done(file_size);
@@ -177,7 +180,7 @@ namespace strategy_complete_ways_with_history {
         }
 
         progress_bar.remove();
-        vout << "Second pass...\n";
+        vout << "Second pass (of two)...\n";
         Pass2 pass2{*this};
         pass2.run(progress_bar, input_file);
         progress_bar.done();
