@@ -1,9 +1,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,15 +20,14 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
-#include <osmium/handler/check_order.hpp>
-
 #include "strategy_simple.hpp"
 #include "../util.hpp"
 
+#include <osmium/handler/check_order.hpp>
+
 namespace strategy_simple {
 
-    Strategy::Strategy(const std::vector<std::unique_ptr<Extract>>& extracts, const osmium::util::Options& options) :
-        ExtractStrategy() {
+    Strategy::Strategy(const std::vector<std::unique_ptr<Extract>>& extracts, const osmium::Options& options) {
         m_extracts.reserve(extracts.size());
         for (const auto& extract : extracts) {
             m_extracts.emplace_back(*extract);
@@ -49,7 +48,7 @@ namespace strategy_simple {
 
     public:
 
-        Pass1(Strategy& strategy) :
+        explicit Pass1(Strategy& strategy) :
             Pass(strategy) {
         }
 
@@ -103,9 +102,9 @@ namespace strategy_simple {
 
     }; // class Pass1
 
-    void Strategy::run(osmium::util::VerboseOutput& vout, bool display_progress, const osmium::io::File& input_file) {
+    void Strategy::run(osmium::VerboseOutput& vout, bool display_progress, const osmium::io::File& input_file) {
         vout << "Running 'simple' strategy in one pass...\n";
-        const std::size_t file_size = osmium::util::file_size(input_file.filename());
+        const std::size_t file_size = input_file.filename().empty() ? 0 : osmium::file_size(input_file.filename());
         osmium::ProgressBar progress_bar{file_size, display_progress};
 
         Pass1 pass1{*this};
