@@ -42,7 +42,7 @@ namespace strategy_smart {
         osmium::index::IdSetDense<osmium::unsigned_object_id_type> relation_ids;
         osmium::index::IdSetDense<osmium::unsigned_object_id_type> extra_relation_ids;
 
-        void add_relation(const osmium::Relation& relation);
+        void add_relation_members(const osmium::Relation& relation);
         void add_relation_parents(osmium::unsigned_object_id_type id, const osmium::index::RelationsMapIndex& map);
     };
 
@@ -56,6 +56,9 @@ namespace strategy_smart {
 
         std::vector<std::string> m_types;
 
+        std::size_t m_complete_partial_relations_percentage = 100;
+
+        bool check_members_count(const std::size_t size, const std::size_t wanted_members) const noexcept;
         bool check_type(const osmium::Relation& relation) const noexcept;
 
     public:
