@@ -1,9 +1,9 @@
 /*
 
 Osmium -- OpenStreetMap data manipulation command line tool
-http://osmcode.org/osmium-tool/
+https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2017  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2018  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,19 +20,20 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 */
 
+#include "exception.hpp"
+#include "util.hpp"
+
+#include <osmium/io/file.hpp>
+#include <osmium/tags/tags_filter.hpp>
+#include <osmium/util/file.hpp>
+#include <osmium/util/string.hpp>
+
+#include <cassert>
 #include <cstdlib>
 #include <iostream>
 #include <string>
 #include <vector>
 
-#include <osmium/io/file.hpp>
-#include <osmium/util/file.hpp>
-#include <osmium/util/string.hpp>
-#include <osmium/tags/tags_filter.hpp>
-
-#include "exception.hpp"
-#include "util.hpp"
-
 /**
  * Get the suffix of the given file name. The suffix is everything after
  * the *first* dot (.). So multiple suffixes will all be returned.
@@ -69,7 +70,7 @@ std::size_t file_size_sum(const std::vector<osmium::io::File>& files) {
     std::size_t sum = 0;
 
     for (const auto& file : files) {
-        sum += osmium::util::file_size(file.filename());
+        sum += osmium::file_size(file.filename());
     }
 
     return sum;
@@ -89,8 +90,11 @@ osmium::osm_entity_bits::type get_types(const std::string& str) {
             case 'r':
                 entities |= osmium::osm_entity_bits::relation;
                 break;
+            case 'a':
+                entities |= osmium::osm_entity_bits::area;
+                break;
             default:
-                throw argument_error{std::string{"Unknown object type '"} + c + "' (allowed are 'n', 'w', and 'r')."};
+                throw argument_error{std::string{"Unknown object type '"} + c + "' (allowed are 'n', 'w', 'r', and 'a')."};
         }
     }
 
@@ -178,7 +182,7 @@ osmium::TagMatcher get_tag_matcher(const std::string& expression) {
     return osmium::TagMatcher{get_string_matcher(key), get_string_matcher(value), invert};
 }
 
-void initialize_tags_filter(osmium::TagsFilter& tags_filter, bool default_result, const std::vector<std::string>& strings) {
+void initialize_tags_filter(osmium::TagsFilter& tags_filter, const bool default_result, const std::vector<std::string>& strings) {
     tags_filter.set_default_result(default_result);
     for (const auto& str : strings) {
         assert(!str.empty());
@@ -193,14 +197,34 @@ osmium::Box parse_bbox(const std::string& str, const std::string& option_name) {
         throw argument_error{std::string{"Need exactly four coordinates in "} + option_name + " option."};
     }
 
-    const osmium::Location bottom_left{std::atof(coordinates[0].c_str()), std::atof(coordinates[1].c_str())};
-    const osmium::Location top_right{std::atof(coordinates[2].c_str()), std::atof(coordinates[3].c_str())};
+    osmium::Location location1;
+    location1.set_lon(coordinates[0].c_str());
+    location1.set_lat(coordinates[1].c_str());
 
-    if (bottom_left.x() < top_right.x() &&
-        bottom_left.y() < top_right.y()) {
-        return osmium::Box{bottom_left, top_right};
-    }
+    osmium::Location location2;
+    location2.set_lon(coordinates[2].c_str());
+    location2.set_lat(coordinates[3].c_str());
 
-    throw argument_error{std::string{"Need LEFT < RIGHT and BOTTOM < TOP in "} + option_name + " option."};
+    osmium::Box box;
+    box.extend(location1);
+    box.extend(location2);
+
+    return box;
+}
+
+osmium::item_type parse_item_type(const std::string& t) {
+    if (t == "n" || t == "node") {
+        return osmium::item_type::node;
+    }
+
+    if (t == "w" || t == "way") {
+        return osmium::item_type::way;
+    }
+
+    if (t == "r" || t == "relation") {
+        return osmium::item_type::relation;
+    }
+
+    throw argument_error{std::string{"Unknown default type '"} + t + "' (Allowed are 'node', 'way', and 'relation')."};
 }
 
